summaryrefslogtreecommitdiffstats
path: root/kate/part/katetextline.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:22:15 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:22:15 -0600
commit1180237ab336226ad932d767a6cb56208314988f (patch)
tree0a29b4d5d237f445dc87cb65b00d604ad4aa686d /kate/part/katetextline.h
parenta51cd9949c4e6c726a84a61de3cfadd30cefb5c7 (diff)
downloadtdelibs-1180237ab336226ad932d767a6cb56208314988f.tar.gz
tdelibs-1180237ab336226ad932d767a6cb56208314988f.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'kate/part/katetextline.h')
-rw-r--r--kate/part/katetextline.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kate/part/katetextline.h b/kate/part/katetextline.h
index 84df82908..3922d04d0 100644
--- a/kate/part/katetextline.h
+++ b/kate/part/katetextline.h
@@ -145,10 +145,10 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
* Gets the text as a tqunicode representation
* @return text of this line as TQChar array
*/
- inline const TQChar *text() const { return m_text.tqunicode(); }
+ inline const TQChar *text() const { return m_text.unicode(); }
/**
* Highlighting array
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
*/
private:
/**
* text of line as tqunicode
*/
TQString m_text;
@@ -145,10 +145,10 @@ class KateTextLine : public KShared
inline TQChar getChar (uint pos) const { return m_text[pos]; }
/**
- * Gets the text as a tqunicode representation
+ * Gets the text as a unicode representation
* @return text of this line as TQChar array
*/
@@ -419,7 +419,7 @@ class KateTextLine : public KShared
private:
/**
- * text of line as tqunicode
+ * text of line as unicode
*/
TQString m_text;